@@ -79,7 +79,11 @@ export type ProvListProps = {
   onPageChange?: (page: number, fetchCallback: any) => void
   onSortChange?: (sort: ListsSorting | null, fetchCallback: any) => void
 
+  avatarFallback?: string | ((item: any) => JSX.Element | JSX.Element[] | null)
   avatarField?: string
+  cardsOnRow?: number
+  cardsOnRowCompactScreen?: number
+  cardsOnRowWideScreen?: number
   defaultSort?: ListsSorting
   emptyListText?: boolean | string
   providedFilters?: ListsProvidedFilters
@@ -92,6 +96,8 @@ export type ProvListProps = {
   pagination?: boolean
   primaryField?: string
   primaryComponent?: React.ElementType
+  renderItemActions?: (item: any, index?: number, arr?: any[]) => JSX.Element | JSX.Element[] | null
+  renderItemCardHeaderActions?: (item: any, index?: number, arr?: any[]) => JSX.Element | JSX.Element[] | null
   secondaryField?: ListsField
   secondaryComponent?: React.ElementType
   requestPath: RequestApiPath | string
@@ -102,6 +108,7 @@ export type ProvListProps = {
   textTotalCountAll?: string | boolean
   unsortedOption?: boolean | string
   urlStateStorage?: UrlStateStorage
+  variant?: 'list' | 'cards'
 
   items?: any[]
   itemsCount?: number
@@ -139,6 +146,7 @@ export type ProvTableProps = {
 
   columns: ProvTableColumns
 
+  avatarFallback?: string | ((item: any) => JSX.Element | JSX.Element[] | null)
   avatarField?: string
   entityCaption?: string
   defaultSort?: ListsSorting
