@@ -9,7 +9,7 @@ __all__ = [
     'PERMISSION'
 ]
 
-APP_ICON = media_res_url('icons/mail-accounts.svg')
+APP_ICON = media_res_url('icons/mail-accounts.png')
 
 MSG_APP_CAPTION = lazy_gettext("Mails", 'system.mail')
 MSG_PERMISSION = lazy_gettext("Administer mails", 'system.mail')
